==> haskell-shakespeare-2.1.0.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shakespeare
version:              2.1.0.1
visibility:           public
id:                   shakespeare-2.1.0.1-BpqwlEZhwbU6qjA4jgfdGT
key:                  shakespeare-2.1.0.1-BpqwlEZhwbU6qjA4jgfdGT
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  95fb8172a323a2de0b0241fba743df83
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.0.1-BpqwlEZhwbU6qjA4jgfdGT
depends:
    aeson-2.1.2.1-GLiPeiAR7ZSFwx9H49aVEA base-4.16.4.0
    blaze-html-0.9.2.0-6Obf0pDfpLV1qrK2k7xIGC
    blaze-markup-0.8.3.0-HgAxg6afY1T5WT2tOLveMb bytestring-0.11.4.0
    containers-0.6.5.1 directory-1.3.6.2 exceptions-0.10.4
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND ghc-prim-0.8.0
    parsec-3.1.15.0 process-1.6.16.0
    scientific-0.3.7.0-AhGrLmDpKSMIIBlCI9itHR template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-4Y4A6Wn35BzvWquDAxs4Y
    vector-0.13.1.0-Il4qKxVtRccCcBZCzPMWy6

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.1.0.1-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shakespeare
version:              2.1.0.1
visibility:           public
id:                   shakespeare-2.1.0.1-3loHst4quNh1ay40qOzUAz
key:                  shakespeare-2.1.0.1-3loHst4quNh1ay40qOzUAz
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  7884aef57839c38f371fa4da83e313da
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.0.1-3loHst4quNh1ay40qOzUAz
depends:
    aeson-2.1.2.1-9T6l6SxZl5u1C3PaFHxalW base-4.16.4.0
    blaze-html-0.9.2.0-Ji5j64Spyzt5Tj6Tm60vv0
    blaze-markup-0.8.3.0-D8JC0oXdxdVGAJJuQxYUcB bytestring-0.11.4.0
    containers-0.6.5.1 directory-1.3.6.2 exceptions-0.10.4
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND ghc-prim-0.8.0
    parsec-3.1.15.0 process-1.6.16.0
    scientific-0.3.7.0-JDywD8dnuxJJkMv2HmTQaQ template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-AzoOiKjV26Z32LkoSmNfI7
    vector-0.13.1.0-JX40x5KeA95953did9SvPW

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
